@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.048-9-gf5bf9ab
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.049-6-ge8fdf52
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.049';
+our $VERSION = '0.050';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -77,13 +77,18 @@ has index_base_url => (
     is => 'ro', isa => 'Str',
 );
 
+has run_under_travis => (
+    is => 'ro', isa => 'Bool',
+    default => 0,
+);
+
 around dump_config => sub
 {
     my ($orig, $self) = @_;
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        (map { $_ => $self->$_ ? 1 : 0 } qw(check_all_plugins check_all_prereqs)),
+        (map { $_ => $self->$_ ? 1 : 0 } qw(check_all_plugins check_all_prereqs run_under_travis)),
         phase => $self->phase,
         skip => [ sort $self->skip ],
         modules => [ sort $self->_raw_modules ],
@@ -97,6 +102,12 @@ sub before_build
 {
     my $self = shift;
 
+    if ($ENV{CONTINUOUS_INTEGRATION} and not $self->run_under_travis)
+    {
+        $self->log_debug('travis detected: skipping checks...');
+        return;
+    }
+
     if ($self->phase eq 'build')
     {
         my @extra_modules = $self->_modules_extra;
@@ -119,6 +130,8 @@ sub after_build
 {
     my $self = shift;
 
+    return if $ENV{CONTINUOUS_INTEGRATION} and not $self->run_under_travis;
+
     if ($self->phase eq 'build' and $self->check_all_prereqs)
     {
         if (my @modules = $self->_modules_prereq) {
@@ -475,7 +488,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.049
+version 0.050
 
 =head1 SYNOPSIS
 
@@ -555,6 +568,15 @@ When provided, uses this base URL to fetch F<02packages.details.txt.gz>
 instead of the default C<http://www.cpan.org>.  Use this when your
 distribution uses prerequisites found only in your darkpan-like server.
 
+=head2 C<run_under_travis>
+
+It is possible to detect when a build is being run via L<Travis Continuous Integration|https://travis-ci.org/>.
+Since version 0.035, Travis builds act like other non-interactive builds, where missing modules result in a warning
+instead of a prompt. As of version 0.050, stale checks are only performed for the build phase on Travis builds when
+C<run_under_travis> is set to a true value.
+
+The default value is false.
+
 =for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release
 
 =head1 METHODS
